@@ -4,18 +4,25 @@ import sys
 from pathlib import Path
 from typing import List
 
-from openpyxl import load_workbook
-
 import engine.use_cases.parsing
-from engine.config import Config, check_for_blank, check_for_datamap
+from engine.config import (
+    Config,
+    check_for_blank,
+    check_for_datamap,
+    delete_config_file,
+    show_config_file,
+)
 from engine.exceptions import DatamapNotCSVException
 from engine.repository.datamap import InMemorySingleDatamapRepository
 from engine.repository.master import MasterOutputRepository
-from engine.repository.templates import (InMemoryPopulatedTemplatesRepository,
-                                         MultipleTemplatesWriteRepo)
+from engine.repository.templates import (
+    InMemoryPopulatedTemplatesRepository,
+    MultipleTemplatesWriteRepo,
+)
 from engine.use_cases.output import WriteMasterToTemplates
 from engine.use_cases.parsing import CreateMasterUseCase
 from engine.utils.extraction import data_validation_report, datamap_reader
+from openpyxl import load_workbook
 
 logging.basicConfig(
     level=logging.INFO,
@@ -48,7 +55,9 @@ def check_aux_files(config: Config):
     # if we get this far, there is a datamap file, so we can run this
     dm_name = config.config_parser["DEFAULT"]["datamap file name"]
     if datamap_reader(config.PLATFORM_DOCS_DIR / "input" / dm_name):
-        logger.info("Datamap file passes tests. Check any WARNING messages. Ok to proceed.")
+        logger.info(
+            "Datamap file passes tests. Check any WARNING messages. Ok to proceed."
+        )
     else:
         logger.critical("Datamap tests failed")
 
@@ -118,3 +127,16 @@ def import_and_create_master(echo_funcs, datamap=None):
             master_fn, Path(Config.PLATFORM_DOCS_DIR / "output")
         )
     )
+
+
+def delete_config(config) -> None:
+    try:
+        delete_config_file(config)
+    except FileNotFoundError:
+        logger.critical(
+            f"Could not find {config.DATAMAPS_LIBRARY_CONFIG_FILE}. Run datamaps config restart to recreate it and reset defaults."
+        )
+
+
+def show_config(config) -> None:
+    show_config_file(config)
