@@ -1,6 +1,7 @@
 import getpass
 import logging
 import os
+import sys
 import platform
 import textwrap
 from configparser import ConfigParser
@@ -31,7 +32,9 @@ class Config:
 
     # Specifically for Github Actions CI
     USER_NAME = (
-        os.environ["GITHUB_ACTIONS_RUNNER"] if os.environ.get("GITHUB_ACTIONS_RUNNER") else getpass.getuser()
+        os.environ["GITHUB_ACTIONS_RUNNER"]
+        if os.environ.get("GITHUB_ACTIONS_RUNNER")
+        else getpass.getuser()
     )
 
     DATAMAPS_LIBRARY_DATA_DIR = user_data_dir("datamaps-data", USER_NAME)
@@ -53,6 +56,8 @@ class Config:
     datamap file name = datamap.csv
     blank file name = blank_template.xlsm
 
+    TEMPLATE_ROW_LIMIT = 500
+
     [PATHS]
     document directory = {0}
     input directory = {1}
@@ -72,12 +77,24 @@ class Config:
             )
             Path(cls.DATAMAPS_LIBRARY_CONFIG_DIR).mkdir(parents=True)
         if not Path(cls.DATAMAPS_LIBRARY_CONFIG_FILE).exists():
-            logger.info(f"Creating config file at {cls.DATAMAPS_LIBRARY_CONFIG_FILE}.")
+            # logger.info(f"Creating config file at {cls.DATAMAPS_LIBRARY_CONFIG_FILE}.")
             Path(cls.DATAMAPS_LIBRARY_CONFIG_FILE).write_text(cls.base_config)
-        cls.config_parser.read(cls.DATAMAPS_LIBRARY_CONFIG_FILE)
 
-        Path(cls.DATAMAPS_LIBRARY_CONFIG_FILE).write_text(cls.base_config)
         cls.config_parser.read(cls.DATAMAPS_LIBRARY_CONFIG_FILE)
+        cls.TEMPLATE_ROW_LIMIT = cls.config_parser.defaults().get("template_row_limit")
+        if cls.TEMPLATE_ROW_LIMIT is not None:
+            cls.TEMPLATE_ROW_LIMIT = int(cls.TEMPLATE_ROW_LIMIT)
+        if cls.TEMPLATE_ROW_LIMIT == 0 or cls.TEMPLATE_ROW_LIMIT is None:
+            logger.warning(
+                f"Row limit is missing or set to 0. Recreating config file and resetting to defaults."
+            )
+            delete_config_file(cls)
+        elif cls.TEMPLATE_ROW_LIMIT < 50:
+            logger.warning(
+                f"Row limit is set to {cls.TEMPLATE_ROW_LIMIT} (default is 500). This may be unintentionally low. Check datamaps import templates --help"
+            )
+        else:
+            logger.info(f"Row limit is set to {cls.TEMPLATE_ROW_LIMIT}.")
 
         # then we need to create the docs directory if it doesn't exist
         try:
@@ -104,9 +121,9 @@ def check_for_blank(config: Config) -> Tuple[bool, str]:
     Config should be initialised before passing to this function.
     """
     blank = (
-            config.PLATFORM_DOCS_DIR
-            / "input"
-            / config.config_parser["DEFAULT"]["blank file name"]
+        config.PLATFORM_DOCS_DIR
+        / "input"
+        / config.config_parser["DEFAULT"]["blank file name"]
     )
     if blank.exists():
         return (True, blank.name)
@@ -120,11 +137,29 @@ def check_for_datamap(config: Config) -> Tuple[bool, str]:
     Config should be initialised before passing to this function.
     """
     dm = (
-            config.PLATFORM_DOCS_DIR
-            / "input"
-            / config.config_parser["DEFAULT"]["datamap file name"]
+        config.PLATFORM_DOCS_DIR
+        / "input"
+        / config.config_parser["DEFAULT"]["datamap file name"]
     )
     if dm.exists():
         return (True, dm.name)
     else:
         return (False, "")
+
+
+def delete_config_file(config: Config) -> None:
+    """Deletes the configuration file - config.ini."""
+    try:
+        os.remove(config.DATAMAPS_LIBRARY_CONFIG_FILE)
+        logger.info(
+            f"Configuration reset to default. The necessary configuration files will be recreated on next execution of any datamaps command."
+        )
+    except FileNotFoundError:
+        raise
+
+
+def show_config_file(config: Config) -> None:
+    """
+    Shows the path of the configuration file, config.ini.
+    """
+    logger.info(f"The configuration file is at {config.DATAMAPS_LIBRARY_CONFIG_FILE}")
