@@ -1,15 +1,16 @@
 import json
 from pathlib import Path
-from typing import List, Union
+from typing import Dict, List, Union
 
 from engine.utils.extraction import datamap_reader
+
 from ..domain.datamap import DatamapLine
 from ..exceptions import DatamapNotCSVException
 from ..serializers.datamap import DatamapEncoder
 
 
 class InMemorySingleDatamapRepository:
-    def __init__(self, datamap_path: Union[Path, str]):
+    def __init__(self, datamap_path: Union[Path, str]) -> None:
         self.datamap_path = datamap_path
 
     def list_as_json(self) -> str:
