@@ -6,29 +6,30 @@ import hashlib
 import json
 import logging
 import os
-from collections import OrderedDict
+import re
+from collections import OrderedDict, defaultdict
 from dataclasses import dataclass
 from itertools import groupby
 from pathlib import Path
 from typing import Any, Dict, List, NamedTuple, Union
 from zipfile import BadZipFile
 
-from openpyxl import load_workbook
-from openpyxl.worksheet.cell_range import MultiCellRange
-from openpyxl.worksheet.worksheet import Worksheet
-
+from engine.config import Config  # noqa
 from engine.domain.datamap import DatamapFile, DatamapLine, DatamapLineValueType
 from engine.domain.template import TemplateCell
 from engine.exceptions import (
     DatamapFileEncodingError,
+    DatamapNotCSVException,
     MalFormedCSVHeaderException,
     MissingCellKeyError,
     MissingLineError,
     MissingSheetFieldError,
     NoApplicableSheetsInTemplateFiles,
-    DatamapNotCSVException,
 )
 from engine.utils import ECHO_FUNC_GREEN, ECHO_FUNC_YELLOW
+from openpyxl import load_workbook
+from openpyxl.worksheet.cell_range import MultiCellRange
+from openpyxl.worksheet.worksheet import Worksheet
 
 FILE_DATA = Dict[str, Union[str, Dict[str, Dict[str, str]]]]
 DAT_DATA = Dict[str, FILE_DATA]
@@ -80,7 +81,7 @@ def datamap_reader(dm_file: Union[Path, str]) -> List[DatamapLine]:
         raise
     data = []
     logger.info(f"Reading datamap {dm_file}")
-    logger.info(f"Checking that datamap is valid.")
+    logger.info("Checking that datamap is valid.")
     with DatamapFile(dm_file) as datamap_file:
         reader = csv.DictReader(datamap_file)
         for line in reader:
@@ -325,7 +326,7 @@ def _extract_cellrefs(lst_of_tcs: SHEET_DATA_IN_LST):
         result_lst = list(group)
         if len(result_lst) > 1:
             raise RuntimeError(
-                f"Found duplicate sheet/cellref item when extracting keys."
+                "Found duplicate sheet/cellref item when extracting keys."
             )
         result_item = result_lst[0]
         output.update({k: result_item})
@@ -386,8 +387,8 @@ def datamap_check(dm_file):
                 # test for first char being ascii - if not, likely wrong encoding
                 if not top_row[0][0].isascii():
                     raise DatamapFileEncodingError(
-                        f"Incorrect encoding of datamap file. Please ensure "
-                        f"it is saved in Excel using CSV (Comma delimited) type - not CSV UTF-8 (Comma delimited) type."
+                        "Incorrect encoding of datamap file. Please ensure "
+                        "it is saved in Excel using CSV (Comma delimited) type - not CSV UTF-8 (Comma delimited) type."
                     )
                 else:
                     raise MalFormedCSVHeaderException(
@@ -399,8 +400,8 @@ def datamap_check(dm_file):
                 )
             if not top_row[0][0].isascii():
                 raise DatamapFileEncodingError(
-                    f"Incorrect encoding of datamap file. Please ensure "
-                    f"it is saved in Excel using CSV (Comma delimited) type - not CSV UTF-8 (Comma delimited) type."
+                    "Incorrect encoding of datamap file. Please ensure "
+                    "it is saved in Excel using CSV (Comma delimited) type - not CSV UTF-8 (Comma delimited) type."
                 )
             if top_row[-1] not in _good_type:
                 # test if we are using type column here
@@ -435,7 +436,10 @@ def datamap_check(dm_file):
 
 
 def template_reader(template_file) -> Dict[str, Dict[str, Dict[Any, Any]]]:
-    "Given a populated xlsx file, returns all data in a list of TemplateCell objects."
+    """Given a populated xlsx file, returns all data in a list of TemplateCell objects
+
+    This test uses a fully formatted template file.
+    ."""
     logger.info(f"Starting import of {template_file}.")
     inner_dict: Dict[str, Dict[Any, Any]] = {"data": {}}
     f_path: Path = Path(template_file)
@@ -444,7 +448,7 @@ def template_reader(template_file) -> Dict[str, Dict[str, Dict[Any, Any]]]:
     except TypeError:
         msg = (
             "Unable to open {}. Potential corruption of file. Try resaving "
-            "in Excel or removing conditionally formatting. See issue at "
+            "in Excel or removing conditional formatting. See issue at "
             "https://github.com/hammerheadlemon/bcompiler-engine/issues/3 for update. Quitting.".format(
                 f_path
             )
@@ -462,7 +466,10 @@ def template_reader(template_file) -> Dict[str, Dict[str, Dict[Any, Any]]]:
     for sheet in workbook.worksheets:
         sheet_data: SHEET_DATA_IN_LST = []
         sheet_dict: Dict[str, Dict[str, Dict[str, str]]] = {}
+        rowcnt = 0
         for row in sheet.rows:
+            if rowcnt > int(Config.TEMPLATE_ROW_LIMIT):
+                break
             for cell in row:
                 if cell.value is not None:
                     try:
@@ -485,6 +492,7 @@ def template_reader(template_file) -> Dict[str, Dict[str, Dict[Any, Any]]]:
                             template_file, sheet.title, cellref, val, c_type
                         ).to_dict()
                     sheet_data.append(t_cell)
+            rowcnt += 1
         sheet_dict.update({sheet.title: _extract_cellrefs(sheet_data)})
         holding.append(sheet_dict)
     for sd in holding:
