@@ -1,5 +1,7 @@
 import pytest
 
+from pathlib import Path
+
 from engine.domain.datamap import DatamapLineValueType
 from engine.exceptions import (
     DatamapFileEncodingError,
@@ -14,6 +16,11 @@ DATE = DatamapLineValueType.DATE
 TEXT = DatamapLineValueType.TEXT
 
 
+def test_datamap_file_as_pathlib_object(datamap):
+    data = datamap_reader(Path(datamap))
+    assert len(data) == 18
+
+
 @pytest.mark.parametrize(
     "datamap_csv_unsupported_encodings",
     [
@@ -139,15 +146,13 @@ def test_datamap_with_three_headers(datamap_three_headers):
 
 
 def test_datamap_missing_sheet_fields(datamap_missing_fields):
-    """We do not want the datamap read to pass if a line has a missing sheet field.
-    """
+    """We do not want the datamap read to pass if a line has a missing sheet field."""
     with pytest.raises(MissingSheetFieldError):
         data = datamap_reader(datamap_missing_fields)  # noqa
 
 
 def test_datamap_missing_key_fields(datamap_missing_key_fields):
-    """We do not want the datamap read to pass if a line has a missing key field.
-    """
+    """We do not want the datamap read to pass if a line has a missing key field."""
     with pytest.raises(MissingCellKeyError):
         data = datamap_reader(datamap_missing_key_fields)  # noqa
 
